@@ -4,7 +4,8 @@
                             error = function(e) return(""))
   txt <- paste0("\n### Welcome to semPower ", semPowerVersion, " ###",
                 "\n",
-                "\nSee https://github.com/moshagen/semPower for quick examples and a detailed manual.",
+                "\nSee https://github.com/moshagen/semPower for quick examples.",
+                "\nSee https://moshagen.github.io/semPower/ for a detailed manual.",
                 "\n",
                 "\nPlease cite as:",
                 "\nMoshagen, M., & Erdfelder, E. (2016). A new strategy for testing structural equation models.",
@@ -12,3 +13,5 @@
                 "\n")
   packageStartupMessage(txt)
 }
+
+
